@@ -1,3 +1,5 @@
+import os
+
 CLASSIFIERS = """\
 Development Status :: 3 - Alpha
 Intended Audience :: Science/Research
@@ -13,7 +15,10 @@ Operating System :: MacOS
 """
 
 NAME        = 'numscons'
-VERSION     = '0.4.2.1'
+MAJOR       = 0
+MINOR       = 8
+MICRO       = 0
+DEV         = False
 DESCRIPTION = 'Enable to use scons within distutils to build extensions'
 CLASSIFIERS = filter(None, CLASSIFIERS.split('\n'))
 AUTHOR      = 'David Cournapeau'
@@ -21,6 +26,23 @@ AUTHOR_EMAIL = 'david@ar.media.kyoto-u.ac.jp'
 PACKAGES    = ['numscons', 'numscons.core', 'numscons.checkers',
                'numscons.tools', 'numscons.numdist',
                'numscons.checkers.tests', 'numscons.checkers.fortran']
-PACKAGE_DATA = {'numscons.core' : ['compiler.cfg', 'fcompiler.cfg'], 
+PACKAGE_DATA = {'numscons.core' : ['compiler.cfg', 'fcompiler.cfg', 'cxxcompiler.cfg'], 
               'numscons.checkers' : ['perflib.cfg']}
 DATA_DIR    = ['numscons/scons-local']
+
+def build_verstring():
+    return '%d.%d.%d' % (MAJOR, MINOR, MICRO)
+
+def build_fverstring():
+    if DEV:
+        return build_verstring() + 'dev'
+    else:
+        return build_verstring()
+
+def write_version():
+    fname = os.path.join("numscons", "version.py")
+    f = open(fname, "w")
+    f.writelines("VERSION = '%s'\n" % build_verstring())
+    f.writelines("DEV = %s" % DEV)
+    f.close()
+    
